diff --git a/scripts/langindex.json b/scripts/langindex.json
index aebe2caf0..c741bd67b 100644
--- a/scripts/langindex.json
+++ b/scripts/langindex.json
@@ -546,7 +546,7 @@
"addon.mod_choice.userchoosethisoption": "choice",
"addon.mod_choice.yourselection": "choice",
"addon.mod_data.actionsmenu": "data",
- "addon.mod_data.addentries": "data",
+ "addon.mod_data.add": "data",
"addon.mod_data.advancedsearch": "data",
"addon.mod_data.alttext": "data",
"addon.mod_data.approve": "data",
diff --git a/src/addons/mod/data/components/index/addon-mod-data-index.html b/src/addons/mod/data/components/index/addon-mod-data-index.html
index d521f8e60..c2bf4e15b 100644
--- a/src/addons/mod/data/components/index/addon-mod-data-index.html
+++ b/src/addons/mod/data/components/index/addon-mod-data-index.html
@@ -4,8 +4,8 @@
-
+
@@ -111,8 +111,8 @@
-
+
- {{ 'addon.mod_data.addentries' | translate }}
+ {{ 'addon.mod_data.add' | translate }}
diff --git a/src/addons/mod/data/lang.json b/src/addons/mod/data/lang.json
index 53248678c..ae33b24cd 100644
--- a/src/addons/mod/data/lang.json
+++ b/src/addons/mod/data/lang.json
@@ -1,6 +1,6 @@
{
"actionsmenu": "Actions menu",
- "addentries": "Add entries",
+ "add": "Add entry",
"advancedsearch": "Advanced search",
"alttext": "Alternative text",
"approve": "Approve",
diff --git a/src/addons/mod/data/tests/behat/entries.feature b/src/addons/mod/data/tests/behat/entries.feature
index 6b1a1a3bf..503207096 100644
--- a/src/addons/mod/data/tests/behat/entries.feature
+++ b/src/addons/mod/data/tests/behat/entries.feature
@@ -30,7 +30,7 @@ Feature: Users can manage entries in database activities
Scenario: Create entry
Given I entered the data activity "Web links" on course "Course 1" as "student1" in the app
Then I should find "No entries yet" in the app
- When I press "Add entries" in the app
+ When I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodle.org/ |
| Description | Moodle community site |
@@ -48,13 +48,13 @@ Feature: Users can manage entries in database activities
And I entered the data activity "Web links" on course "Course 1" as "student1" in the app
# TODO Create and use a generator for database entries.
- When I press "Add entries" in the app
+ When I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodle.org/ |
| Description | Moodle community site |
And I press "Save" near "Web links" in the app
And I entered the data activity "Web links" on course "Course 1" as "student2" in the app
- And I press "Add entries" in the app
+ And I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodlecloud.com/ |
| Description | Moodle Cloud |
@@ -80,7 +80,7 @@ Feature: Users can manage entries in database activities
And I should find "Moodle Cloud" in the app
Given I entered the data activity "Data with comments" on course "Course 1" as "student1" in the app
- When I press "Add entries" in the app
+ When I press "Add entry" in the app
And I set the following fields to these values in the app:
| Description | Moodle community site |
And I press "Save" near "Data with comments" in the app
@@ -102,7 +102,7 @@ Feature: Users can manage entries in database activities
Scenario: Students can not edit or delete other user's entries from list and single view in the app
Given I entered the data activity "Web links" on course "Course 1" as "student1" in the app
- And I press "Add entries" in the app
+ And I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodle.org/ |
| Description | Moodle community site |
@@ -119,7 +119,7 @@ Feature: Users can manage entries in database activities
Scenario: Delete entry (student) & Update entry (student)
Given I entered the data activity "Web links" on course "Course 1" as "student1" in the app
- And I press "Add entries" in the app
+ And I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodle.org/ |
| Description | Moodle community site |
@@ -150,7 +150,7 @@ Feature: Users can manage entries in database activities
And I should not find "Moodle Cloud" in the app
# Repeat again with single view.
- Given I press "Add entries" in the app
+ Given I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodle.org/ |
| Description | Moodle community site |
@@ -185,12 +185,12 @@ Feature: Users can manage entries in database activities
Scenario: Delete entry (teacher) & Update entry (teacher)
Given I entered the data activity "Web links" on course "Course 1" as "student1" in the app
- And I press "Add entries" in the app
+ And I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodle.org/ |
| Description | Moodle community site |
And I press "Save" near "Web links" in the app
- And I press "Add entries" in the app
+ And I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://telegram.org/ |
| Description | Telegram |
@@ -261,7 +261,7 @@ Feature: Users can manage entries in database activities
| database | type | name | description |
| data2 | number | Number | Number value |
And I entered the data activity "Number DB" on course "Course 1" as "student1" in the app
- When I press "Add entries" in the app
+ When I press "Add entry" in the app
And I press "Save" near "Number DB" in the app
Then I should find "You did not fill out any fields!" in the app
diff --git a/src/addons/mod/data/tests/behat/sync.feature b/src/addons/mod/data/tests/behat/sync.feature
index d367f96c5..4d2b12f38 100644
--- a/src/addons/mod/data/tests/behat/sync.feature
+++ b/src/addons/mod/data/tests/behat/sync.feature
@@ -31,7 +31,7 @@ Feature: Users can store entries in database activities when offline and sync wh
Given I entered the data activity "Web links" on course "Course 1" as "student1" in the app
And I switch network connection to offline
And I should find "No entries yet" in the app
- When I press "Add entries" in the app
+ When I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodle.org/ |
| Description | Moodle community site |
@@ -49,7 +49,7 @@ Feature: Users can store entries in database activities when offline and sync wh
Scenario: Update entry (offline) & Delete entry (offline)
Given I entered the data activity "Web links" on course "Course 1" as "student1" in the app
And I should find "No entries yet" in the app
- And I press "Add entries" in the app
+ And I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodle.org/ |
| Description | Moodle community site |
@@ -101,7 +101,7 @@ Feature: Users can store entries in database activities when offline and sync wh
Scenario: Students can undo deleting entries to a database in the app while offline
Given I entered the data activity "Web links" on course "Course 1" as "student1" in the app
And I should find "No entries yet" in the app
- And I press "Add entries" in the app
+ And I press "Add entry" in the app
And I set the following fields to these values in the app:
| URL | https://moodle.org/ |
| Description | Moodle community site |
diff --git a/src/core/features/comments/tests/behat/basic_usage.feature b/src/core/features/comments/tests/behat/basic_usage.feature
index c376ddf19..2af2285ae 100644
--- a/src/core/features/comments/tests/behat/basic_usage.feature
+++ b/src/core/features/comments/tests/behat/basic_usage.feature
@@ -30,7 +30,7 @@ Feature: Test basic usage of comments in app
Scenario: Add comments & Delete comments (database)
# Create database entry and comment as a teacher
Given I entered the data activity "Data" on course "Course 1" as "teacher1" in the app
- And I press "Add entries" in the app
+ And I press "Add entry" in the app
And I set the field "Test field name" to "Test" in the app
And I press "Save" in the app
And I press "Actions menu" in the app
@@ -69,7 +69,7 @@ Feature: Test basic usage of comments in app
Scenario: Add comments offline & Delete comments offline & Sync comments (database)
Given I entered the data activity "Data" on course "Course 1" as "teacher1" in the app
- And I press "Add entries" in the app
+ And I press "Add entry" in the app
And I set the field "Test field name" to "Test" in the app
And I press "Save" in the app
And I press "Actions menu" in the app
diff --git a/src/addons/mod/data/components/index/index.ts b/src/addons/mod/data/components/index/index.ts
index 94264157d..9c341aebf 100644
--- a/src/addons/mod/data/components/index/index.ts
+++ b/src/addons/mod/data/components/index/index.ts
@@ -487,9 +487,9 @@ export class AddonModDataIndexComponent extends CoreCourseModuleMainActivityComp
}
/**
* Opens add entries form.
*/
- gotoAddEntries(): void {
+ gotoAddEntry(): void {
const params: Params = {
title: this.module.name,
group: this.selectedGroup,
@@ -487,9 +487,9 @@ export class AddonModDataIndexComponent extends CoreCourseModuleMainActivityComp
}
/**
- * Opens add entries form.
+ * Opens add entry form.
*/